-- ****************************************************************************
-- * Licensed Materials - Property of IBM
-- * 5724-T40 IBM License Metric Tool
-- * 5724-S94 IBM Tivoli Asset Discovery for Distributed
-- *
-- * (C) Copyright IBM Corp. 2012.  All Rights Reserved.
-- *
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- ****************************************************************************

connect to tlma%

create procedure ADM.DROP_IF_EXISTS(in NAME char(100))
	begin
	declare STMT char(250);
	declare MSG char(20);
	
	declare continue handler for sqlstate '42704' set MSG = 'ok';
	
	set STMT = 'DROP ' concat NAME;
	prepare S1 from STMT;
	execute S1;
	end%

MERGE INTO ADM.CONTROL cv USING (VALUES ('VM_MANAGER_DC_ENABLED')) 
	AS v (NAME) ON cv.NAME = v.NAME 
	WHEN NOT MATCHED THEN INSERT VALUES ('VM_MANAGER_DC_ENABLED', 'false')%

UPDATE ADM.CONTROL SET 	VALUE = 'false' WHERE NAME = 'VM_MANAGER_DC_ENABLED'%
	
ALTER TABLE ADM.VM_MANAGER ADD COLUMN MODE SMALLINT NOT NULL DEFAULT 0%
ALTER TABLE ADM.VM_MANAGER ADD COLUMN LAST_MERGE_TIME timestamp%
REORG TABLE ADM.VM_MANAGER%

comment on column ADM.VM_MANAGER.MODE is 
     'VM Manager mode: 0=direct, 1=stand-alone. The 0 is default value.'%	

comment on column ADM.VM_MANAGER.LAST_MERGE_TIME is 
     'Time of the last successful data merge for given VM Manager.'%	     
     
call ADM.DROP_IF_EXISTS('index ADM.VM_MAN_UI1')%     
     
create index ADM.VM_MAN_UI1 on ADM.VM_MANAGER
(
    URL
)%

call ADM.DROP_IF_EXISTS('trigger VIRT.ROOT_D1')%    

create trigger VIRT.ROOT_D1
    after delete on VIRT.ROOT
    referencing old as OLD for each row mode db2sql
    delete from VIRT.DECOMISSIONING
    where VIRT.DECOMISSIONING.PARENT_ID = OLD.ID%

call ADM.DROP_IF_EXISTS('trigger VIRT.ROOT_D2')%    
    
create trigger VIRT.ROOT_D2
    after delete on VIRT.ROOT
    referencing old as OLD for each row mode db2sql
    delete from VIRT.CLUSTER
    where VIRT.CLUSTER.PARENT_ID = OLD.ID%

call ADM.DROP_IF_EXISTS('trigger VIRT.ROOT_D3')%    
    
create trigger VIRT.ROOT_D3
    after delete on VIRT.ROOT
    referencing old as OLD for each row mode db2sql
    delete from VIRT.HOST
    where VIRT.HOST.PARENT_ID = OLD.ID AND VIRT.HOST.PARENT_TYPE = 0%    

call ADM.DROP_IF_EXISTS('trigger VIRT.CLUSTER_D1')%    
    
create trigger VIRT.CLUSTER_D1
    after delete on VIRT.CLUSTER
    referencing old as OLD for each row mode db2sql
    delete from VIRT.HOST
    where VIRT.HOST.PARENT_ID = OLD.ID AND VIRT.HOST.PARENT_TYPE = 1%   
    
call ADM.DROP_IF_EXISTS('trigger VIRT.HOST_D1')%    
    
create trigger VIRT.HOST_D1
    after delete on VIRT.HOST
    referencing old as OLD for each row mode db2sql
    delete from VIRT.GUEST
    where VIRT.GUEST.PARENT_ID = OLD.ID%      
    
REORG TABLE ADM.VM_MANAGER%
runstats on table ADM.VM_MANAGER and indexes all%
     
MERGE INTO LIC.CONTROL_VALUES cv 
USING (VALUES ('vmManagerMergerTime')) 
	AS v (CONTROL_KEY) ON cv.CONTROL_KEY = v.CONTROL_KEY 
WHEN NOT MATCHED THEN
	INSERT VALUES ('vmManagerMergerTime', '18:00', 1, null, null, null, 0, 'Hour of day')%

MERGE INTO LIC.CONTROL_VALUES cv 
USING (VALUES ('maxVMManagerInactivity')) 
	AS v (CONTROL_KEY) ON cv.CONTROL_KEY = v.CONTROL_KEY 
WHEN NOT MATCHED THEN
	INSERT VALUES ('maxVMManagerInactivity', '5760', 0, 1440, 20160, null, 0, 'Minutes')%
	
MERGE INTO LIC.CONTROL_VALUES cv 
USING (VALUES ('maxWaitingForVMData')) 
	AS v (CONTROL_KEY) ON cv.CONTROL_KEY = v.CONTROL_KEY 
WHEN NOT MATCHED THEN
	INSERT VALUES ('maxWaitingForVMData', '7', 0, 1, 30, null, 0, 'days')%	

MERGE INTO LIC.CONTROL_VALUES cv 
USING (VALUES ('numberOfVMManagerCollectorThreads')) 
	AS v (CONTROL_KEY) ON cv.CONTROL_KEY = v.CONTROL_KEY 
WHEN NOT MATCHED THEN
	INSERT VALUES ('numberOfVMManagerCollectorThreads', '0', 0, 0, 32, null, 0, 'Integer')%		
	
MERGE INTO LIC.CONTROL_VALUES cv 
USING (VALUES ('numberOfVMManagerMergerThreads')) 
	AS v (CONTROL_KEY) ON cv.CONTROL_KEY = v.CONTROL_KEY 
WHEN NOT MATCHED THEN
	INSERT VALUES ('numberOfVMManagerMergerThreads', '0', 0, 0, 32, null, 0, 'Integer')%	
	
MERGE INTO ADM.CONTROL cv USING (VALUES ('FIRST_TO_RECALCULATE_DAY')) 
	AS v (NAME) ON cv.NAME = v.NAME 
	WHEN NOT MATCHED THEN INSERT VALUES ('FIRST_TO_RECALCULATE_DAY', '')%	
	
UPDATE ADM.CONTROL SET 	VALUE = '' WHERE NAME = 'FIRST_TO_RECALCULATE_DAY'%
	
ALTER TABLE VIRT.ROOT ADD COLUMN SCAN_DATE timestamp%
ALTER TABLE VIRT.ROOT ADD COLUMN PROCESSED smallint DEFAULT 0 NOT NULL%

comment on column VIRT.ROOT.SCAN_DATE is 
     'The date of the data collection from vm manager.'%	
     
comment on column VIRT.ROOT.PROCESSED is 
     'Flag to indicate whether given scan results was already processed and can be removed. (0-pending, 1-already processed)'%	
     
REORG TABLE VIRT.ROOT%

alter table VIRT.GUEST drop constraint GUEST_HOST_FK%

update adm.oid set BLOCK_SIZE = 1 where lower(TABLE_NAME) = 'adm.vm_manager'%

drop procedure ADM.DROP_IF_EXISTS%

disconnect current%